@@ -4,15 +4,18 @@
 # file 'LICENSE', which is part of this source code package.
 #       Copyright (c) 2011 R Pratap Chakravarthy
 
+"""Common library functions and utility functions specific to tayra package."""
+
 import re
-from   xml.etree    import ElementTree
+from   xml.etree                import ElementTree
 
 def etx2html( etxconfig={}, etxloc=None, etxtext=None, **kwargs ):
-    """Convert eazytext content either supplied as a file (containing the text)
-    or as raw-text, into html.
+    """TBD : Convert eazytext content either supplied as a file (containing
+    the text) or as raw-text, into html.
 
     ``etxconfig``,
-        Configuration parameters for eazytext. A deep-copy of this will be used.
+        configuration parameters for eazytext. A deep-copy of this will be
+        used.
     ``etxloc``,
         file location, either in asset specification format, or absolute path.
     ``etxtext``
@@ -27,6 +30,10 @@ def etx2html( etxconfig={}, etxloc=None, etxtext=None, **kwargs ):
     return t( context={} )
 
 def directive_tokens( s ):
+    """Directives are meta constructs that provide more information on how to
+    interpret a template text. Typically a directive starts with a **@**
+    followed by directive name and one or more tokens and/or attributes
+    pairs."""
     parts = list( filter( None, s.split(' ') ))
     typ = parts.pop(0)
     params = []
